<?php

/**
 * bp_code_snippets_register_widgets
 * register code snippets widget.
 */

function bp_code_snippets_register_widgets() {
	add_action('widgets_init', create_function('', 'return register_widget("BP_Code_Snippets_Widget");') );
}
add_action( 'plugins_loaded', 'bp_code_snippets_register_widgets' );

class BP_Code_Snippets_Widget extends WP_Widget {

	function bp_code_snippets_widget() {
		parent::WP_Widget( false, $name = __( 'Snippets Widget', 'bp-code-snippets' ) );
	}

	function widget( $args, $instance ) {
		global $bp;

		extract( $args );

		echo $before_widget;
		if($instance['custom_name']){
			echo $before_title .
				 $instance['custom_name'].
			     $after_title;
		}
		else echo $before_title .
			 $widget_name.
		     $after_title; ?>

	<?php if(bp_code_snippets_num_active_user()>0 || bp_code_snippets_info_current_group($bp->groups->current_group->id)>0):?>
		<div class="item-options" id="links-list-options">
			<?php
			if($instance['display_mode']=="most-commented") $title_widget = __('Most commented snippets','bp-code-snippets');
			elseif($instance['display_mode']=="recently-commented") $title_widget = __('Recently commented snippets','bp-code-snippets');
			else $title_widget = __('Latest snippets','bp-code-snippets');
			echo $title_widget;
			?>
		</div>
		<?php bp_code_snippets_widget_list($instance['per_page'], $instance['display_mode']);?>
	<?php else:?>
		<div class="widget-error">
			<?php _e('There are no public snippets to display.', 'bp-code-snippets') ?>
		</div>
	<?php endif;?>

	<?php echo $after_widget; ?>
	<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['custom_name'] = strip_tags( $new_instance['custom_name'] );
		$instance['per_page'] = strip_tags( $new_instance['per_page'] );
		$instance['display_mode'] = strip_tags( $new_instance['display_mode'] );

		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'custom_name' => 'Snippets','per_page' => 5, 'display_mode' => 'date' ) );
		$custom_name = strip_tags( $instance['custom_name'] );
		$per_page = strip_tags( $instance['per_page'] );
		$display_mode = strip_tags( $instance['display_mode'] );
		?>
		
		<p><label for="bp-snippets-widget-custom-name"><?php _e( 'Title:', 'bp-code-snippets' ); ?> <input class="widefat" id="<?php echo $this->get_field_id( 'custom_name' ); ?>" name="<?php echo $this->get_field_name( 'custom_name' ); ?>" type="text" value="<?php echo attribute_escape( $custom_name ); ?>" style="width: 80%" /></label></p>
		<p><label for="bp-snippets-widget-per-page"><?php _e( 'Number of Snippets:', 'bp-code-snippets' ); ?> <input class="widefat" id="<?php echo $this->get_field_id( 'per_page' ); ?>" name="<?php echo $this->get_field_name( 'per_page' ); ?>" type="text" value="<?php echo attribute_escape( $per_page ); ?>" style="width: 30%" /></label></p>
		<p><label for="bp-snippets-widget-display-mode"><?php _e( 'Displaying mode:', 'bp-code-snippets' ); ?> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'display_mode' ); ?>" name="<?php echo $this->get_field_name( 'display_mode' ); ?>">
				<option value="latest" <?php if(attribute_escape( $display_mode ) =='latest') echo 'selected';?>><?php _e('Latest','bp-code-snippets');?></option>
				<option value="most-commented" <?php if(attribute_escape( $display_mode ) =='most-commented') echo 'selected';?>><?php _e('Most commented','bp-code-snippets');?></option>
				<option value="recently-commented" <?php if(attribute_escape( $display_mode ) =='recently-commented') echo 'selected';?>><?php _e('Recently commented','bp-code-snippets');?></option>
			</select>
			</label>
		</p>
		
	<?php
	}
}

/**
 * bp_code_snippets_widget_list
 * send the html for the widget and sort the query (most commented or by date)
 */

function bp_code_snippets_widget_list($limit=2, $display){
	global $bp, $wpdb;
	$table_group = $wpdb->base_prefix.'bp_groups';
	if($display =='most-commented') $order = 'cs_comment_count';
	elseif($display == 'recently-commented') $order ='date_comment';
	else $order = 'date_cs';
	if($order!='date_comment'){
		if($bp->current_component == "groups" && !bp_is_home() && bp_is_single_item()){
			$group_id = $bp->groups->current_group->id;
			$public_snippets = $wpdb->get_results("SELECT id_cs, id_group, id_user, date_cs, snippet_title, snippet_type, snippet_purpose, cs_comment_count FROM ".$bp->snippets->table_name_snippets." WHERE id_group='$group_id' ORDER BY ".$order." DESC LIMIT 0,".$limit);
		}
		else{
			$public_snippets = $wpdb->get_results("SELECT id_cs, id_group, id_user, date_cs, snippet_title, snippet_type, snippet_purpose, cs_comment_count FROM ".$bp->snippets->table_name_snippets." LEFT JOIN ".$table_group." ON(".$bp->snippets->table_name_snippets.".id_group = ".$table_group.".id) WHERE ".$table_group.".status='public' ORDER BY ".$order." DESC LIMIT 0,".$limit);
		}
		?>
		<ul id="links-list" class="item-list">
		<?php if(count($public_snippets)>0):?>
		<?php foreach($public_snippets as $snippet):?>
			<?php 
			$user_info = get_userdata($snippet->id_user);
			$group_info = bp_code_snippet_get_infos_goup($snippet->id_group);
			$group_permalink = site_url().'/'.BP_GROUPS_SLUG.'/'.$group_info->slug.'/';
			$snippet_permalink = $group_permalink.BP_CS_SLUG.'/';
			if($bp->current_component=="groups" && $group_info->status!="public" && groups_is_user_member( $bp->loggedin_user->id, $snippet->id_group )!=1){
				?>
				<li><?php _e('This group is private, no Code Snippets can be shown!', 'bp-code-snippets');?></li>
				<?php
				break;
			}else{
				?>
					<li>
						<div class="item-avatar">
							<a href="<?php echo site_url() ?>/<?php echo BP_MEMBERS_SLUG ;?>/<?php echo $user_info->user_nicename;?>" title="<?php echo $user_info->user_nicename;?>" rel="nofollow">
							<?php echo bp_core_fetch_avatar('item_id=' . $snippet->id_user . '&type=full&width=32&height=32' ) ?>
							</a>
						</div>

						<div class="item">
							<div class="item-title"><a href="<?php echo $snippet_permalink.'single/'.$snippet->id_cs;?>" title="<?php _e('Read more', 'bp-code-snippets');?>"><?php echo stripslashes($snippet->snippet_title); ?></a></div>
							<div class="item-meta"><span class="activity"><?php printf( __( '%d comment(s)', 'bp-code-snippets' ), $snippet->cs_comment_count ) ?></span></div>
						</div>
					</li>
					<?php
				}
					?>
		<?php endforeach;?>
		<?php elseif( $bp->current_component == "groups" && !groups_get_groupmeta( $bp->groups->current_group->id, 'snippets_code_ok' ) ):?>
			<li><?php _e('This group is not using BP Code Snippets', 'bp-code-snippets');?></li>
		<?php else:?>
			<li><?php _e('No Snippet available yet!', 'bp-code-snippets');?></li>
		<?php endif;?>
		</ul>
		<?php
	}
	else{
		if($bp->current_component == "groups" && !bp_is_home() && bp_is_single_item()){
			$group_id = $bp->groups->current_group->id;
			$public_snippets = $wpdb->get_results("SELECT C.cs_id, C2.latest, ".$bp->snippets->table_name_snippets.".id_cs, ".$bp->snippets->table_name_snippets.".id_group, ".$bp->snippets->table_name_snippets.".id_user, ".$bp->snippets->table_name_snippets.".snippet_title, COUNT( * ) AS ct
			FROM ".$bp->snippets->table_name_comments." C
			JOIN (SELECT MAX( date_comment ) AS latest FROM ".$bp->snippets->table_name_comments." GROUP BY cs_id)C2 ON C2.latest = C.date_comment
			LEFT JOIN ".$bp->snippets->table_name_snippets." ON ( ".$bp->snippets->table_name_snippets.".id_cs = C.cs_id ) 
			WHERE id_group =  '$group_id'
			GROUP BY C.cs_id ORDER BY ".$order." DESC LIMIT 0,".$limit);
		}
		else{			
			$public_snippets = $wpdb->get_results("SELECT C.cs_id, C2.latest, ".$bp->snippets->table_name_snippets.".id_cs, ".$bp->snippets->table_name_snippets.".id_group, ".$bp->snippets->table_name_snippets.".id_user, ".$bp->snippets->table_name_snippets.".snippet_title, wp_bp_groups.status, COUNT(*) AS ct FROM ".$bp->snippets->table_name_comments." C 
			JOIN (SELECT MAX(date_comment) AS latest FROM ".$bp->snippets->table_name_comments." GROUP BY cs_id) C2 ON C2.latest = C.date_comment 
			LEFT JOIN ".$bp->snippets->table_name_snippets." ON(".$bp->snippets->table_name_snippets.".id_cs=C.cs_id) 
			LEFT JOIN ".$table_group." ON (".$bp->snippets->table_name_snippets.".id_group = ".$table_group.".id) 
			WHERE ".$table_group.".status='public' GROUP BY C.cs_id ORDER BY C.".$order." DESC LIMIT 0,".$limit);
		}
		?>
		<ul id="links-list" class="item-list">
		<?php if(count($public_snippets)>0):?>
		<?php foreach($public_snippets as $snippet):?>
			<?php 
			$user_info = get_userdata($snippet->id_user);
			$group_info = bp_code_snippet_get_infos_goup($snippet->id_group);
			$group_permalink = site_url().'/'.BP_GROUPS_SLUG.'/'.$group_info->slug.'/';
			$snippet_permalink = $group_permalink.BP_CS_SLUG.'/';
			if($bp->current_component=="groups" && $group_info->status!="public" && groups_is_user_member( $bp->loggedin_user->id, $snippet->id_group )!=1){
				?>
				<li><?php _e('This group is private, no Code Snippets can be shown!', 'bp-code-snippets');?></li>
				<?php
				break;
			}else{
				?>
					<li>
						<div class="item-avatar">
							<a href="<?php echo site_url() ?>/<?php echo BP_MEMBERS_SLUG ;?>/<?php echo $user_info->user_nicename;?>" title="<?php echo $user_info->user_nicename;?>" rel="nofollow">
							<?php echo bp_core_fetch_avatar('item_id=' . $snippet->id_user . '&type=full&width=32&height=32' ) ?>
							</a>
						</div>

						<div class="item">
							<div class="item-title"><a href="<?php echo $snippet_permalink.'single/'.$snippet->id_cs;?>" title="<?php _e('Read more', 'bp-code-snippets');?>"><?php echo stripslashes($snippet->snippet_title); ?></a></div>
							<div class="item-meta"><span class="activity"><?php _e( 'Last comment on', 'bp-code-snippets' );?>&nbsp;<?php echo mysql2date(get_option('date_format'), $snippet->latest);?></span></div>
						</div>
					</li>
					<?php
				}
					?>
		<?php endforeach;?>
		<?php elseif( $bp->current_component == "groups" && !groups_get_groupmeta( $bp->groups->current_group->id, 'snippets_code_ok' ) ):?>
			<li><?php _e('This group is not using BP Code Snippets', 'bp-code-snippets');?></li>
		<?php else:?>
			<li><?php _e('No Snippet available yet!', 'bp-code-snippets');?></li>
		<?php endif;?>
		</ul>
		<?php
	}
}
?>